@@ -301,10 +301,19 @@ class TestBidiRpc(object):
         assert bidi_rpc._initial_request is None
         assert not bidi_rpc._callbacks
 
-    def test_close_no_rpc(self):
+    def test_close_with_no_rpc(self):
         bidi_rpc = bidi.BidiRpc(None)
         bidi_rpc.close()
 
+        assert bidi_rpc.call is None
+        assert bidi_rpc.is_active is False
+        # ensure the request queue was signaled to stop.
+        assert bidi_rpc.pending_requests == 1
+        assert bidi_rpc._request_queue.get() is None
+        # ensure request and callbacks are cleaned up
+        assert bidi_rpc._initial_request is None
+        assert not bidi_rpc._callbacks
+
     def test_send(self):
         rpc, call = make_rpc()
         bidi_rpc = bidi.BidiRpc(rpc)
@@ -828,7 +837,13 @@ class TestBackgroundConsumer(object):
         bidi_rpc._start_rpc.side_effect = expected_exception
 
         consumer = bidi.BackgroundConsumer(bidi_rpc, on_response=None)
+
         consumer.start()
+
+        # Wait for the consumer's thread to exit.
+        while consumer.is_active:
+            pass  # pragma: NO COVER
+
         assert callback.call_args.args[0] == grpc.StatusCode.INVALID_ARGUMENT
 
     def test_consumer_expected_error(self, caplog):
@@ -918,3 +933,33 @@ class TestBackgroundConsumer(object):
         error_logs = [r.message for r in caplog.records if r.levelname == "ERROR"]
         assert not error_logs, f"Found unexpected ERROR logs: {error_logs}"
         bidi_rpc.is_active = False
+
+    def test_fatal_exceptions_can_inform_consumer(self, caplog):
+        """
+        https://github.com/googleapis/python-api-core/issues/820
+        Exceptions thrown in the BackgroundConsumer not caught by `should_recover` / `should_terminate`
+        on the RPC should be bubbled back to the caller through `on_fatal_exception`, if passed.
+        """
+        caplog.set_level(logging.DEBUG)
+
+        for fatal_exception in (
+            ValueError("some non-api error"),
+            exceptions.PermissionDenied("some api error"),
+        ):
+            bidi_rpc = mock.create_autospec(bidi.ResumableBidiRpc, instance=True)
+            bidi_rpc.is_active = True
+            on_response = mock.Mock(spec=["__call__"])
+
+            on_fatal_exception = mock.Mock(spec=["__call__"])
+
+            bidi_rpc.open.side_effect = fatal_exception
+
+            consumer = bidi.BackgroundConsumer(
+                bidi_rpc, on_response, on_fatal_exception
+            )
+
+            consumer.start()
+            # let the background thread run for a while before exiting
+            time.sleep(0.1)
+
+            on_fatal_exception.assert_called_once_with(fatal_exception)
